@@ -4,6 +4,7 @@
 import time
 import threading
 import logging
+import ssl
 from queue import Queue
 import socket
 from velbus.connections.connection import VelbusConnection
@@ -18,7 +19,7 @@ class SocketConnection(VelbusConnection):
     :author: Maikel Punie <maikel.punie@gmail.com>
     """
 
-    def __init__(self, device, controller=None):
+    def __init__(self, device, controller=None, tls=False):
         VelbusConnection.__init__(self)
         self.logger = logging.getLogger("velbus")
         self._device = device
@@ -28,6 +29,12 @@ class SocketConnection(VelbusConnection):
         addr = (addr[0], int(addr[1]))
         try:
             self._socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            if tls:
+                ctx = ssl._create_unverified_context()
+                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                self._socket = ctx.wrap_socket(sock)
+            else:
+                self._socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self._socket.connect(addr)
         except Exception:
             self.logger.error(
