@@ -171,7 +171,7 @@ class Controller(object):
                     callback()
 
             # 180 second timeout for loading modules
-            self.load_timeout = threading.Timer(180, timeout_expired).start()
+            self.load_timeout = threading.Timer(360, timeout_expired).start()
             for module in self._modules:
                 self._modules[module].load(module_loaded)
 
@@ -242,6 +242,8 @@ class Controller(object):
         if name in ModuleRegistry:
             module = ModuleRegistry[name](m_type, name, address, self)
             self._add_module(address, module)
+        elif name in ["VMBSIG", "VMBUSBIP"]:
+            self.logger.info("Module " + name + " is a config module, ignoring")
         else:
             self.logger.warning("Module " + name + " is not yet supported")
 
